@@ -203,6 +203,11 @@ def process_version(versionstr):
     
     if __main__.change_type == "build":
         build = int(build) + 1    
+        
+    if __main__.change_type == "prerelease":
+        if __main__.debug == 1:
+            print("Prerelease version value: ", __main__.pre_value)
+        prelease_version = __main__.pre_value
     
     if version_format == "standard":
         new_version = str(major) + '.' + str(minor) + '.' + str(patch)
